CardioResult class

Constructors

CardioResult({int? heartRate, String? confidence, int? systolicBp, int? diastolicBp, int? spo2, int? respiratoryRate, int? hrv})
CardioResult.fromJson(Map<String, dynamic> json)
factory

Properties

confidence String?
final
diastolicBp int?
final
hashCode int
The hash code for this object.
no setterinherited
heartRate int?
final
hrv int?
final
respiratoryRate int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spo2 int?
final
systolicBp int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited